@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+from _thread import allocate_lock
 from AccessControl.PermissionRole import rolesForPermissionOn
 from plone.app.caching.interfaces import IETagValue
 from plone.app.caching.interfaces import IPloneCacheSettings
@@ -7,7 +7,6 @@ from plone.memoize.interfaces import ICacheChooser
 from plone.registry.interfaces import IRegistry
 from Products.CMFCore.interfaces import IContentish
 from Products.CMFCore.interfaces import ISiteRoot
-from thread import allocate_lock
 from z3c.caching.interfaces import ILastModified
 from zope.annotation.interfaces import IAnnotations
 from zope.component import getUtility
@@ -24,20 +23,18 @@ import time
 import wsgiref.handlers
 
 
-PAGE_CACHE_KEY = 'plone.app.caching.operations.ramcache'
-PAGE_CACHE_ANNOTATION_KEY = 'plone.app.caching.operations.ramcache.key'
-ETAG_ANNOTATION_KEY = 'plone.app.caching.operations.etag'
-LASTMODIFIED_ANNOTATION_KEY = 'plone.app.caching.operations.lastmodified'
+PAGE_CACHE_KEY = "plone.app.caching.operations.ramcache"
+PAGE_CACHE_ANNOTATION_KEY = "plone.app.caching.operations.ramcache.key"
+ETAG_ANNOTATION_KEY = "plone.app.caching.operations.etag"
+LASTMODIFIED_ANNOTATION_KEY = "plone.app.caching.operations.lastmodified"
 _marker = object()
 
-logger = logging.getLogger('plone.app.caching')
+logger = logging.getLogger("plone.app.caching")
 
 parseETagLock = allocate_lock()
-# etagQuote = re.compile('(\s*\"([^\"]*)\"\s*,{0,1})')
-# etagNoQuote = re.compile('(\s*([^,]*)\s*,{0,1})')
 
-etagQuote = re.compile('(\s*(W\/)?\"([^\"]*)\"\s*,?)')
-etagNoQuote = re.compile('(\s*(W\/)?([^,]*)\s*,?)')
+etagQuote = re.compile(r'(\s*(W\/)?"([^"]*)"\s*,?)')
+etagNoQuote = re.compile(r"(\s*(W\/)?([^,]*)\s*,?)")
 
 #
 # Operation helpers, used in the implementations of interceptResponse() and
@@ -56,7 +53,7 @@ def setCacheHeaders(
     smaxage=None,
     etag=None,
     lastModified=None,
-    vary=None
+    vary=None,
 ):
     """General purpose dispatcher to set various cache headers
 
@@ -76,7 +73,7 @@ def setCacheHeaders(
             smaxage=smaxage,
             etag=etag,
             lastModified=lastModified,
-            vary=vary
+            vary=vary,
         )
 
     elif smaxage:
@@ -87,7 +84,7 @@ def setCacheHeaders(
             smaxage,
             etag=etag,
             lastModified=lastModified,
-            vary=vary
+            vary=vary,
         )
 
     elif etag or lastModified:
@@ -96,7 +93,7 @@ def setCacheHeaders(
             request,
             response,
             etag=etag,
-            lastModified=lastModified
+            lastModified=lastModified,
         )
 
     else:
@@ -112,11 +109,11 @@ def doNotCache(published, request, response):
     expire immediately and disable validation.
     """
 
-    if response.getHeader('Last-Modified'):
-        del response.headers['last-modified']
+    if response.getHeader("Last-Modified"):
+        del response.headers["last-modified"]
 
-    response.setHeader('Expires', formatDateTime(getExpiration(0)))
-    response.setHeader('Cache-Control', 'max-age=0, must-revalidate, private')
+    response.setHeader("Expires", formatDateTime(getExpiration(0)))
+    response.setHeader("Cache-Control", "max-age=0, must-revalidate, private")
 
 
 def cacheInBrowser(published, request, response, etag=None, lastModified=None):
@@ -132,15 +129,15 @@ def cacheInBrowser(published, request, response, etag=None, lastModified=None):
     """
 
     if etag is not None:
-        response.setHeader('ETag', '"{0}"'.format(etag), literal=1)
+        response.setHeader("ETag", f'"{etag}"', literal=1)
 
     if lastModified is not None:
-        response.setHeader('Last-Modified', formatDateTime(lastModified))
-    elif response.getHeader('Last-Modified'):
-        del response.headers['last-modified']
+        response.setHeader("Last-Modified", formatDateTime(lastModified))
+    elif response.getHeader("Last-Modified"):
+        del response.headers["last-modified"]
 
-    response.setHeader('Expires', formatDateTime(getExpiration(0)))
-    response.setHeader('Cache-Control', 'max-age=0, must-revalidate, private')
+    response.setHeader("Expires", formatDateTime(getExpiration(0)))
+    response.setHeader("Cache-Control", "max-age=0, must-revalidate, private")
 
 
 def cacheInProxy(
@@ -150,7 +147,7 @@ def cacheInProxy(
     smaxage,
     etag=None,
     lastModified=None,
-    vary=None
+    vary=None,
 ):
     """Set headers to cache the response in a caching proxy.
 
@@ -162,22 +159,22 @@ def cacheInProxy(
 
     if lastModified is not None:
         response.setHeader(
-            'Last-Modified',
-            formatDateTime(lastModified)
+            "Last-Modified",
+            formatDateTime(lastModified),
         )
-    elif response.getHeader('Last-Modified'):
-        del response.headers['last-modified']
+    elif response.getHeader("Last-Modified"):
+        del response.headers["last-modified"]
 
     if etag is not None:
-        response.setHeader('ETag', '"{0}"'.format(etag), literal=1)
+        response.setHeader("ETag", f'"{etag}"', literal=1)
 
     if vary is not None:
-        response.setHeader('Vary', vary)
+        response.setHeader("Vary", vary)
 
-    response.setHeader('Expires', formatDateTime(getExpiration(0)))
+    response.setHeader("Expires", formatDateTime(getExpiration(0)))
     response.setHeader(
-        'Cache-Control',
-        'max-age=0, s-maxage={0}, must-revalidate'.format(smaxage),
+        "Cache-Control",
+        f"max-age=0, s-maxage={smaxage}, must-revalidate",
     )
 
 
@@ -189,7 +186,7 @@ def cacheInBrowserAndProxy(
     smaxage=None,
     etag=None,
     lastModified=None,
-    vary=None
+    vary=None,
 ):
     """Set headers to cache the response in the browser and caching proxy if
     applicable.
@@ -202,27 +199,27 @@ def cacheInBrowserAndProxy(
     """
 
     if lastModified is not None:
-        response.setHeader('Last-Modified', formatDateTime(lastModified))
-    elif response.getHeader('Last-Modified'):
-        del response.headers['last-modified']
+        response.setHeader("Last-Modified", formatDateTime(lastModified))
+    elif response.getHeader("Last-Modified"):
+        del response.headers["last-modified"]
 
     if etag is not None:
-        response.setHeader('ETag', '"{0}"'.format(etag), literal=1)
+        response.setHeader("ETag", f'"{etag}"', literal=1)
 
     if vary is not None:
-        response.setHeader('Vary', vary)
+        response.setHeader("Vary", vary)
 
-    response.setHeader('Expires', formatDateTime(getExpiration(maxage)))
+    response.setHeader("Expires", formatDateTime(getExpiration(maxage)))
 
     if smaxage is not None:
-        maxage = '{0}, s-maxage={1}'.format(maxage, smaxage)
+        maxage = f"{maxage}, s-maxage={smaxage}"
 
     # Substituting proxy-validate in place of must=revalidate here because of
     # Safari bug
     # https://bugs.webkit.org/show_bug.cgi?id=13128
     response.setHeader(
-        'Cache-Control',
-        'max-age={0}, proxy-revalidate, public'.format(maxage)
+        "Cache-Control",
+        f"max-age={maxage}, proxy-revalidate, public",
     )
 
 
@@ -232,7 +229,7 @@ def cacheInRAM(
     response,
     etag=None,
     lastModified=None,
-    annotationsKey=PAGE_CACHE_ANNOTATION_KEY
+    annotationsKey=PAGE_CACHE_ANNOTATION_KEY,
 ):
     """Set a flag indicating that the response for the given request
     should be cached in RAM.
@@ -254,7 +251,7 @@ def cacheInRAM(
 
     annotations = IAnnotations(request, None)
     if annotations is None:
-        return None
+        return
 
     key = getRAMCacheKey(request, etag=etag, lastModified=lastModified)
 
@@ -269,7 +266,7 @@ def cachedResponse(
     status,
     headers,
     body,
-    gzip=False
+    gzip=False,
 ):
     """Returned a cached page. Modifies the response (status and headers)
     and returns the cached body.
@@ -283,17 +280,13 @@ def cachedResponse(
     response.setStatus(status)
 
     for k, v in headers.items():
-        if k.lower() == 'etag':
+        if k.lower() == "etag":
             response.setHeader(k, v, literal=1)
         else:
             response.setHeader(k, v)
 
-    response.setHeader('X-RAMCache', PAGE_CACHE_KEY, literal=1)
-
-    if not gzip:
-        response.enableHTTPCompression(request, disable=True)
-    else:
-        response.enableHTTPCompression(request)
+    response.setHeader("X-RAMCache", PAGE_CACHE_KEY, literal=1)
+    response.enableHTTPCompression(request, disable=not gzip)
 
     return body
 
@@ -309,7 +302,7 @@ def notModified(published, request, response, etag=None, lastModified=None):
     """
 
     if etag is not None:
-        response.setHeader('ETag', etag, literal=1)
+        response.setHeader("ETag", f'"{etag}"', literal=1)
 
     # Specs say that Last-Modified MUST NOT be included in a 304
     # and Cache-Control/Expires MUST NOT be included unless they
@@ -322,32 +315,32 @@ def notModified(published, request, response, etag=None, lastModified=None):
     #
     # http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html
     #
-    if response.getHeader('Last-Modified'):
-        del response.headers['last-modified']
-    if response.getHeader('Expires'):
-        del response.headers['expires']
-    if response.getHeader('Cache-Control'):
-        del response.headers['cache-control']
+    if response.getHeader("Last-Modified"):
+        del response.headers["last-modified"]
+    if response.getHeader("Expires"):
+        del response.headers["expires"]
+    if response.getHeader("Cache-Control"):
+        del response.headers["cache-control"]
 
     response.setStatus(304)
-    return u''
+    return ""
 
 
 #
 # Cache checks
 #
 
+
 def cacheStop(request, rulename):
-    """Check for any cache stop variables in the request.
-    """
+    """Check for any cache stop variables in the request."""
 
     # Only cache GET requests
-    if request.get('REQUEST_METHOD') != 'GET':
+    if request.get("REQUEST_METHOD") != "GET":
         return True
 
     # rss_search also uses the SearchableText variable
     # so we'll hard code an exception for now
-    if rulename == 'plone.content.feed':
+    if rulename == "plone.content.feed":
         return False
 
     registry = getUtility(IRegistry)
@@ -373,8 +366,8 @@ def isModified(request, etag=None, lastModified=None):
     if not etag and not lastModified:
         return True
 
-    ifModifiedSince = request.getHeader('If-Modified-Since', None)
-    ifNoneMatch = request.getHeader('If-None-Match', None)
+    ifModifiedSince = request.getHeader("If-Modified-Since", None)
+    ifNoneMatch = request.getHeader("If-None-Match", None)
 
     if ifModifiedSince is None and ifNoneMatch is None:
         return True
@@ -391,18 +384,16 @@ def isModified(request, etag=None, lastModified=None):
             return True
 
         # is the current etag in the list of client-side etags?
-        if etag not in clientETags and '*' not in clientETags:
+        if etag not in clientETags and "*" not in clientETags:
             return True
 
         etagMatched = True
 
-    """
-    If a site turns off etags after having them on, the pages previously
-    served will return an If-None-Match header, but the site will not be
-    configured for etags. In this case, force a refresh to load the
-    latest headers. I interpret this as the spec rule that the
-    etags do NOT match, and therefor we must not return a 304.
-    """
+    # If a site turns off etags after having them on, the pages previously
+    # served will return an If-None-Match header, but the site will not be
+    # configured for etags. In this case, force a refresh to load the
+    # latest headers. I interpret this as the spec rule that the
+    # etags do NOT match, and therefor we must not return a 304.
     if ifNoneMatch and etag is None:
         return True
 
@@ -411,7 +402,7 @@ def isModified(request, etag=None, lastModified=None):
 
         # Attempt to get a date
 
-        ifModifiedSince = ifModifiedSince.split(';')[0]
+        ifModifiedSince = ifModifiedSince.split(";")[0]
         ifModifiedSince = parseDateTime(ifModifiedSince)
 
         if ifModifiedSince is None:
@@ -424,7 +415,7 @@ def isModified(request, etag=None, lastModified=None):
             if (lastModified - ifModifiedSince) > delta_sec:
                 return True
         except TypeError:
-            logger.exception('Could not compare dates')
+            logger.exception("Could not compare dates")
 
         # If we expected an ETag and the client didn't give us one, consider
         # that an error. This may be more conservative than the spec requires.
@@ -435,7 +426,7 @@ def isModified(request, etag=None, lastModified=None):
     return False
 
 
-def visibleToRole(published, role, permission='View'):
+def visibleToRole(published, role, permission="View"):
     """Determine if the published object would be visible to the given
     role.
 
@@ -444,12 +435,19 @@ def visibleToRole(published, role, permission='View'):
     """
     return role in rolesForPermissionOn(permission, published)
 
+
 #
 # Basic helper functions
 #
 
 
-def getContext(published, marker=(IContentish, ISiteRoot,)):
+def getContext(
+    published,
+    marker=(
+        IContentish,
+        ISiteRoot,
+    ),
+):
     """Given a published object, attempt to look up a context
 
     ``published`` is the object that was published.
@@ -458,7 +456,13 @@ def getContext(published, marker=(IContentish, ISiteRoot,)):
     Returns an item providing ``marker`` or None, if it cannot be found.
     """
 
-    if not isinstance(marker, (list, tuple,)):
+    if not isinstance(
+        marker,
+        (
+            list,
+            tuple,
+        ),
+    ):
         marker = (marker,)
 
     def checkType(context):
@@ -468,14 +472,14 @@ def getContext(published, marker=(IContentish, ISiteRoot,)):
         return False
 
     while (
-        published is not None and
-        not checkType(published) and
-        getattr(published, '__parent__')
+        published is not None
+        and not checkType(published)
+        and getattr(published, "__parent__")
     ):
         published = published.__parent__
 
     if not checkType(published):
-        return None
+        return
 
     return published
 
@@ -504,15 +508,22 @@ def parseDateTime(str):
     try:
         dt = dateutil.parser.parse(str)
     except ValueError:
-        return None
+        return
 
     if not dt:
-        return None
+        return
 
     if dt.tzinfo is None:
-        dt = datetime.datetime(dt.year, dt.month, dt.day,
-                               dt.hour, dt.minute, dt.second, dt.microsecond,
-                               dateutil.tz.tzlocal())
+        dt = datetime.datetime(
+            dt.year,
+            dt.month,
+            dt.day,
+            dt.hour,
+            dt.minute,
+            dt.second,
+            dt.microsecond,
+            dateutil.tz.tzlocal(),
+        )
 
     return dt
 
@@ -523,7 +534,7 @@ def getLastModifiedAnnotation(published, request, lastModified=True):
     """
 
     if not lastModified:
-        return None
+        return
 
     annotations = IAnnotations(request, None)
     if annotations is not None:
@@ -547,20 +558,27 @@ def getLastModified(published, lastModified=True):
     """
 
     if not lastModified:
-        return None
+        return
 
     lastModified = ILastModified(published, None)
     if lastModified is None:
-        return None
+        return
 
     dt = lastModified()
     if dt is None:
-        return None
+        return
 
     if dt.tzinfo is None:
-        dt = datetime.datetime(dt.year, dt.month, dt.day,
-                               dt.hour, dt.minute, dt.second, dt.microsecond,
-                               dateutil.tz.tzlocal())
+        dt = datetime.datetime(
+            dt.year,
+            dt.month,
+            dt.day,
+            dt.hour,
+            dt.minute,
+            dt.second,
+            dt.microsecond,
+            dateutil.tz.tzlocal(),
+        )
 
     return dt
 
@@ -575,8 +593,7 @@ def getExpiration(maxage):
     now = datetime.datetime.now()
     if maxage > 0:
         return now + datetime.timedelta(seconds=maxage)
-    else:
-        return now - datetime.timedelta(days=3650)
+    return now - datetime.timedelta(days=3650)
 
 
 def getETagAnnotation(published, request, keys=(), extraTokens=()):
@@ -585,7 +602,7 @@ def getETagAnnotation(published, request, keys=(), extraTokens=()):
     """
 
     if not keys and not extraTokens:
-        return None
+        return
 
     annotations = IAnnotations(request, None)
     if annotations is not None:
@@ -613,23 +630,20 @@ def getETag(published, request, keys=(), extraTokens=()):
 
     All tokens will be concatenated into an ETag string, separated by pipes.
     """
-
     if not keys and not extraTokens:
-        return None
+        return
 
     tokens = []
     noTokens = True
     for key in keys:
-        component = queryMultiAdapter(
-            (published, request), IETagValue, name=key)
+        component = queryMultiAdapter((published, request), IETagValue, name=key)
         if component is None:
-            logger.warning(
-                'Could not find value adapter for ETag component %s', key)
-            tokens.append('')
+            logger.warning("Could not find value adapter for ETag component %s", key)
+            tokens.append("")
         else:
             value = component()
             if value is None:
-                value = ''
+                value = ""
             else:
                 noTokens = False
             tokens.append(value)
@@ -639,10 +653,10 @@ def getETag(published, request, keys=(), extraTokens=()):
         tokens.append(token)
 
     if noTokens:
-        return None
+        return
 
-    etag = '|' + '|'.join(tokens)
-    etag = etag.replace(',', ';')  # commas are bad in etags
+    etag = "|" + "|".join(tokens)
+    etag = etag.replace(",", ";")  # commas are bad in etags
     etag = etag.replace('"', "'")  # double quotes are bad in etags
 
     return etag
@@ -674,20 +688,20 @@ def parseETags(text, allowWeak=True, _result=None):
         if m:
             # Match quoted etag (spec-observing client)
             length = len(m.group(1))
-            value = (m.group(2) or '') + (m.group(3) or '')
+            value = (m.group(2) or "") + (m.group(3) or "")
         else:
             # Match non-quoted etag (lazy client)
             m = etagNoQuote.match(text)
             if m:
                 length = len(m.group(1))
-                value = (m.group(2) or '') + (m.group(3) or '')
+                value = (m.group(2) or "") + (m.group(3) or "")
             else:
                 return result
     finally:
         parseETagLock.release()
 
     if value:
-        if value.startswith('W/'):
+        if value.startswith("W/"):
             if allowWeak:
                 result.append(value[2:])
         else:
@@ -695,6 +709,7 @@ def parseETags(text, allowWeak=True, _result=None):
 
     return parseETags(text[length:], allowWeak=allowWeak, _result=result)
 
+
 #
 # RAM cache management
 #
@@ -711,10 +726,8 @@ def getRAMCache(globalKey=PAGE_CACHE_KEY):
     """
 
     chooser = queryUtility(ICacheChooser)
-    if chooser is None:
-        return None
-
-    return chooser(globalKey)
+    if chooser is not None:
+        return chooser(globalKey)
 
 
 def getRAMCacheKey(request, etag=None, lastModified=None):
@@ -730,16 +743,14 @@ def getRAMCacheKey(request, etag=None, lastModified=None):
     optional but in most cases that are worth caching in RAM, the etag
     is needed to ensure the key changes when the resource view changes.
     """
-
-    resourceKey = '{0}{1}?{2}'.format(
-        request.get('SERVER_URL', ''),
-        request.get('PATH_INFO', ''),
-        request.get('QUERY_STRING', ''),
-    )
+    server_url = request.get("SERVER_URL", "")
+    path_info = request.get("PATH_INFO", "")
+    query_string = request.get("QUERY_STRING", "")
+    resourceKey = f"{server_url}{path_info}?{query_string}"
     if etag:
-        resourceKey = '|' + etag + '||' + resourceKey
+        resourceKey = "|" + etag + "||" + resourceKey
     if lastModified:
-        resourceKey = '|' + str(lastModified) + '||' + resourceKey
+        resourceKey = "|" + str(lastModified) + "||" + resourceKey
     return resourceKey
 
 
@@ -748,7 +759,7 @@ def storeResponseInRAMCache(
     response,
     result,
     globalKey=PAGE_CACHE_KEY,
-    annotationsKey=PAGE_CACHE_ANNOTATION_KEY
+    annotationsKey=PAGE_CACHE_ANNOTATION_KEY,
 ):
     """Store the given response in the RAM cache.
 
@@ -784,7 +795,7 @@ def storeResponseInRAMCache(
     potentially another fix but I doubt long term it's ever the right thing to
     do.
     """
-    if result == '':
+    if not result:
         return
 
     status = response.getStatus()
@@ -799,7 +810,7 @@ def fetchFromRAMCache(
     etag=None,
     lastModified=None,
     globalKey=PAGE_CACHE_KEY,
-    default=None
+    default=None,
 ):
     """Return a page cached in RAM, or None if it cannot be found.
 
@@ -821,10 +832,10 @@ def fetchFromRAMCache(
 
     cache = getRAMCache(globalKey)
     if cache is None:
-        return None
+        return
 
     key = getRAMCacheKey(request, etag=etag, lastModified=lastModified)
     if key is None:
-        return None
+        return
 
     return cache.get(key, default)
